@@ -184,8 +184,10 @@ def _parse_version(version: str) -> PythonVersionInfo:
     match = re.match(r"(\d+)(?:\.(\d+)(?:\.\d+)?)?$", version)
     if match is None:
         raise ValueError(
-            "The given version is not in the right format. "
-            'Use something like "3.2" or "3".'
+            (
+                "The given version is not in the right format. "
+                + 'Use something like "3.2" or "3".'
+            )
         )
 
     major = int(match.group(1))
