@@ -279,6 +279,7 @@ def _execute_transform(  # noqa: C901
             transformer.context,
             filename=filename,
             full_module_name=_calculate_module(config.repo_root, filename),
+            scratch={},
         )
 
         # Run the transform, bail if we failed or if we aren't formatting code
@@ -576,8 +577,12 @@ def parallel_exec_transform_with_prettyprint(  # noqa: C901
     total = len(files)
     progress = Progress(enabled=not hide_progress, total=total)
 
+    chunksize = 4
     # Grab number of cores if we need to
-    jobs: int = jobs if jobs is not None else cpu_count()
+    jobs: int = min(
+        jobs if jobs is not None else cpu_count(),
+        (len(files) + chunksize - 1) // chunksize,
+    )
 
     if jobs < 1:
         raise Exception("Must have at least one job to process!")
@@ -614,7 +619,7 @@ def parallel_exec_transform_with_prettyprint(  # noqa: C901
         python_version=python_version,
     )
 
-    if total == 1:
+    if total == 1 or jobs == 1:
         # Simple case, we should not pay for process overhead.
         # Let's just use a dummy synchronous pool.
         jobs = 1
@@ -646,7 +651,9 @@ def parallel_exec_transform_with_prettyprint(  # noqa: C901
             for filename in files
         ]
         try:
-            for result in p.imap_unordered(_execute_transform_wrap, args, chunksize=4):
+            for result in p.imap_unordered(
+                _execute_transform_wrap, args, chunksize=chunksize
+            ):
                 # Print an execution result, keep track of failures
                 _print_parallel_result(
                     result,
