@@ -16,6 +16,10 @@ from libcst.metadata.expression_context_provider import (
     ExpressionContextProvider,
 )
 from libcst.metadata.full_repo_manager import FullRepoManager
+from libcst.metadata.name_provider import (
+    FullyQualifiedNameProvider,
+    QualifiedNameProvider,
+)
 from libcst.metadata.parent_node_provider import ParentNodeProvider
 from libcst.metadata.position_provider import (
     PositionProvider,
@@ -32,12 +36,12 @@ from libcst.metadata.scope_provider import (
     Assignments,
     BaseAssignment,
     BuiltinAssignment,
+    BuiltinScope,
     ClassScope,
     ComprehensionScope,
     FunctionScope,
     GlobalScope,
     QualifiedName,
-    QualifiedNameProvider,
     QualifiedNameSource,
     Scope,
     ScopeProvider,
@@ -60,6 +64,7 @@ __all__ = [
     "BaseAssignment",
     "Assignment",
     "BuiltinAssignment",
+    "BuiltinScope",
     "Access",
     "Scope",
     "GlobalScope",
@@ -74,6 +79,7 @@ __all__ = [
     "BatchableMetadataProvider",
     "VisitorMetadataProvider",
     "QualifiedNameProvider",
+    "FullyQualifiedNameProvider",
     "ProviderT",
     "Assignments",
     "Accesses",
